==> cabal-helper-0.8.0.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/cabal-helper.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-helper
version: 0.8.0.2
id: cabal-helper-0.8.0.2-7DpkfLXA63QEsXSqQvPN4i
key: cabal-helper-0.8.0.2-7DpkfLXA63QEsXSqQvPN4i
license: AGPL-3
maintainer: dxld@darkboxed.org
synopsis: Simple interface to some of Cabal'\''s configuration state, mainly used by ghc-mod
description:
    Cabal'\''s little helper provides access to build information gathered by
    @cabal@ when configuring a project. Specifically we'\''re interested in
    retrieving enough information to bring up a compiler session, using the GHC
    API, which is similar to running @cabal repl@ in a project.
    .
    While simple in principle this is complicated by the fact that the
    information Cabal writes to disk is in an unstable format and only really
    accessible through the Cabal API itself.
    .
    Since we do not want to bind the user of a development tool which utilises
    this library to a specific version of Cabal we compile the code which
    interfaces with the Cabal library'\''s API on the user'\''s machine, at runtime,
    against whichever version of Cabal was used to write the on disk information
    for a given project.
    .
    If this version of Cabal is not available on the users machine anymore,
    which is fairly likely since cabal-install is usually linked statically, we
    have support for compiling the Cabal library also. In this case the library
    is installed into a private, isolated, package database in
    @$XDG_CACHE_HOME/cabal-helper@ so as to not interfere with the user'\''s
    package database.
category: Distribution
author: Daniel Gröber <dxld@darkboxed.org>
exposed: True
indefinite: False
exposed-modules:
    Distribution.Helper
hidden-modules: CabalHelper.Shared.InterfaceTypes
                CabalHelper.Shared.Sandbox Paths_cabal_helper
abi: 621d09c075774972c3842133d858f645
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cabal-helper-0.8.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/cabal-helper-0.8.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/cabal-helper-0.8.0.2
hs-libraries: HScabal-helper-0.8.0.2-7DpkfLXA63QEsXSqQvPN4i
depends:
    base-4.10.1.0 Cabal-2.0.1.0 directory-1.3.0.2 filepath-1.4.1.2
    transformers-0.5.2.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    process-1.6.1.0 unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    semigroupoids-5.2.2-85MDbRqhEWkFTVTQWF4lc9 ghc-prim-0.5.1.1
    unix-2.7.2.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             Cabal-2.0.1.0=0f36b79494fd1737cec34e8481a8753a
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=5b179f57b538cadc8b677d453ca08cb0
             semigroupoids-5.2.2-85MDbRqhEWkFTVTQWF4lc9=4406e3aa1c02843e73a1ae9e4eaa7009
             ghc-prim-0.5.1.1=c8f3d173544d1472727fce7b0518abda
             unix-2.7.2.2=1e3caa57de79efd01f1c7566785dcafa
haddock-interfaces: /usr/share/doc/cabal-helper/html/cabal-helper.haddock
haddock-html: /usr/share/doc/cabal-helper/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> cabal-helper-0.8.0.2-6-x86_64.pkg.tar.xz: usr/share/haskell/register/cabal-helper.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-helper
version: 0.8.0.2
id: cabal-helper-0.8.0.2-4ixEM718doMEPJD0h2G9bu
key: cabal-helper-0.8.0.2-4ixEM718doMEPJD0h2G9bu
license: AGPL-3
maintainer: dxld@darkboxed.org
synopsis: Simple interface to some of Cabal'\''s configuration state, mainly used by ghc-mod
description:
    Cabal'\''s little helper provides access to build information gathered by
    @cabal@ when configuring a project. Specifically we'\''re interested in
    retrieving enough information to bring up a compiler session, using the GHC
    API, which is similar to running @cabal repl@ in a project.
    .
    While simple in principle this is complicated by the fact that the
    information Cabal writes to disk is in an unstable format and only really
    accessible through the Cabal API itself.
    .
    Since we do not want to bind the user of a development tool which utilises
    this library to a specific version of Cabal we compile the code which
    interfaces with the Cabal library'\''s API on the user'\''s machine, at runtime,
    against whichever version of Cabal was used to write the on disk information
    for a given project.
    .
    If this version of Cabal is not available on the users machine anymore,
    which is fairly likely since cabal-install is usually linked statically, we
    have support for compiling the Cabal library also. In this case the library
    is installed into a private, isolated, package database in
    @$XDG_CACHE_HOME/cabal-helper@ so as to not interfere with the user'\''s
    package database.
category: Distribution
author: Daniel Gröber <dxld@darkboxed.org>
exposed: True
indefinite: False
exposed-modules:
    Distribution.Helper
hidden-modules: CabalHelper.Shared.InterfaceTypes
                CabalHelper.Shared.Sandbox Paths_cabal_helper
abi: ef209e9a5c6c9e505b4d64f6d456d69a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cabal-helper-0.8.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/cabal-helper-0.8.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/cabal-helper-0.8.0.2
hs-libraries: HScabal-helper-0.8.0.2-4ixEM718doMEPJD0h2G9bu
depends:
    base-4.10.1.0 Cabal-2.0.1.0 directory-1.3.0.2 filepath-1.4.1.2
    transformers-0.5.2.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    process-1.6.1.0 unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    semigroupoids-5.2.2-FIKI4eo8Lo755XP0In7exf ghc-prim-0.5.1.1
    unix-2.7.2.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             Cabal-2.0.1.0=0f36b79494fd1737cec34e8481a8753a
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=5b179f57b538cadc8b677d453ca08cb0
             semigroupoids-5.2.2-FIKI4eo8Lo755XP0In7exf=118673e9216db664cff8974364f6a00e
             ghc-prim-0.5.1.1=c8f3d173544d1472727fce7b0518abda
             unix-2.7.2.2=1e3caa57de79efd01f1c7566785dcafa
haddock-interfaces: /usr/share/doc/cabal-helper/html/cabal-helper.haddock
haddock-html: /usr/share/doc/cabal-helper/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
